@@ -64,7 +64,7 @@ class LSMSClient(object):
                 expiration=str(timeout)+'000',
             ),
             body=json.dumps({
-                "text": n,
+                "batch": n,
                 "tokenizer_kwargs": tokenizer_kwargs or {},
                 "generate_kwargs": generate_kwargs or {}
             }).encode())
